==> clean_android_design-0.0.4.tar.gz: lib/src/dialog/default_dialog.dart <==
import 'dart:math';

import 'package:clean_android_design/src/navigator/split_navigator.dart';
import 'package:clean_android_design/src/style/clean_android_design_style.dart';
import 'package:flutter/material.dart';

showCustomDialog(BuildContext context, Widget dialog) async {
  SplitNavigator.of(SplitNavigatorSide.main).push(PageRouteBuilder(
    opaque: false,
    pageBuilder: (
      _,
      __,
      ___,
    ) =>
        DialogBackground(),
    transitionsBuilder: (context, animation, secondaryAnimation, child) =>
        FadeTransition(
      opacity: animation,
      child: child,
    ),
  ));

  await SplitNavigator.of(SplitNavigatorSide.main).push(PageRouteBuilder(
    opaque: false,
    pageBuilder: (_, __, ___) => dialog,
    transitionsBuilder: (context, animation, secondaryAnimation, child) {
      var begin = Offset(0.0, 1.0);
      var end = Offset.zero;
      var tween =
          Tween(begin: begin, end: end).chain(CurveTween(curve: Curves.ease));
      var offsetAnimation = animation.drive(tween);

      return SlideTransition(
        position: offsetAnimation,
        child: FadeTransition(
          opacity: animation,
          child: child,
        ),
      );
    },
  ));
}

class DefaultDialog extends StatelessWidget {
  final Widget title;
  final List<Widget> buttons;
  final bool dismissible;

  const DefaultDialog(
      {Key key, this.title, this.buttons, this.dismissible = true})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    var rowChildren = List<Widget>();
    buttons.asMap().forEach((index, button) {
      if (index != 0)
        rowChildren.add(Padding(
          padding: const EdgeInsets.symmetric(vertical: 3),
          child: VerticalDivider(
            thickness: 1,
          ),
        ));
      rowChildren.add(button);
    });

    return WillPopScope(
      onWillPop: () {
        if (dismissible) {
          Navigator.pop(context);
          Navigator.pop(context);
        }
        return Future.value(false);
      },
      child: Stack(
        children: <Widget>[
          GestureDetector(
            onTap: dismissible
                ? () {
                    Navigator.pop(context);
                    Navigator.pop(context);
                  }
                : null,
            child: Container(
              color: Color.fromRGBO(0, 0, 0, 0),
              width: MediaQuery.of(context).size.width,
              height: MediaQuery.of(context).size.height,
            ),
          ),
          Column(
            children: <Widget>[
              Expanded(child: Container()),
              Container(
                width: min(800, MediaQuery.of(context).size.width),
                padding: EdgeInsets.symmetric(horizontal: 30, vertical: 20),
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(30),
                  color: Colors.white,
                ),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    SizedBox(
                      height: 10,
                    ),
                    DefaultTextStyle(
                        style: TextStyles.textStyleSize(16), child: title),
                    SizedBox(
                      height: 20,
                    ),
                    IntrinsicHeight(child: Row(children: rowChildren)),
                  ],
                ),
              ),
              AnimatedContainer(
                  duration: Duration(milliseconds: 300),
                  curve: Curves.easeOut,
                  height:
                      max(MediaQuery.of(context).viewInsets.bottom + 10, 20)),
            ],
          ),
        ],
      ),
    );
  }
}

class DialogBackground extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container(
      color: Color.fromRGBO(0, 0, 0, 0.5),
      width: MediaQuery.of(context).size.width,
      height: MediaQuery.of(context).size.height,
    );
  }
}

==> clean_android_design-0.0.14.tar.gz: lib/src/dialog/default_dialog.dart <==
import 'dart:math';

import 'package:clean_android_design/src/navigator/split_navigator.dart';
import 'package:clean_android_design/src/style/clean_android_design_style.dart';
import 'package:flutter/material.dart';

showCustomDialog(BuildContext context, Widget dialog) async {
  SplitNavigator.of(SplitNavigatorSide.main).push(PageRouteBuilder(
    opaque: false,
    pageBuilder: (
      _,
      __,
      ___,
    ) =>
        DialogBackground(),
    transitionsBuilder: (context, animation, secondaryAnimation, child) =>
        FadeTransition(
      opacity: animation,
      child: child,
    ),
  ));

  await SplitNavigator.of(SplitNavigatorSide.main).push(PageRouteBuilder(
    opaque: false,
    pageBuilder: (_, __, ___) => dialog,
    transitionsBuilder: (context, animation, secondaryAnimation, child) {
      var begin = Offset(0.0, 1.0);
      var end = Offset.zero;
      var tween =
          Tween(begin: begin, end: end).chain(CurveTween(curve: Curves.ease));
      var offsetAnimation = animation.drive(tween);

      return SlideTransition(
        position: offsetAnimation,
        child: FadeTransition(
          opacity: animation,
          child: child,
        ),
      );
    },
  ));
}

class DefaultDialog extends StatelessWidget {
  final Widget title;
  final List<Widget> buttons;
  final bool dismissible;

  const DefaultDialog(
      {Key key, this.title, this.buttons, this.dismissible = true})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    var rowChildren = <Widget>[];
    buttons.asMap().forEach((index, button) {
      if (index != 0)
        rowChildren.add(Padding(
          padding: const EdgeInsets.symmetric(vertical: 3),
          child: VerticalDivider(
            thickness: 1,
          ),
        ));
      rowChildren.add(button);
    });

    return WillPopScope(
      onWillPop: () {
        if (dismissible) {
          Navigator.pop(context);
          Navigator.pop(context);
        }
        return Future.value(false);
      },
      child: Stack(
        children: <Widget>[
          GestureDetector(
            onTap: dismissible
                ? () {
                    Navigator.pop(context);
                    Navigator.pop(context);
                  }
                : null,
            child: Container(
              color: Color.fromRGBO(0, 0, 0, 0),
              width: MediaQuery.of(context).size.width,
              height: MediaQuery.of(context).size.height,
            ),
          ),
          Column(
            children: <Widget>[
              Expanded(child: Container()),
              Container(
                width: min(800, MediaQuery.of(context).size.width),
                padding: EdgeInsets.symmetric(horizontal: 30, vertical: 20),
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(30),
                  color: Colors.white,
                ),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    SizedBox(
                      height: 10,
                    ),
                    DefaultTextStyle(
                        style: TextStyles.textStyleSize(16), child: title),
                    SizedBox(
                      height: 20,
                    ),
                    IntrinsicHeight(child: Row(children: rowChildren)),
                  ],
                ),
              ),
              AnimatedContainer(
                  duration: Duration(milliseconds: 300),
                  curve: Curves.easeOut,
                  height:
                      max(MediaQuery.of(context).viewInsets.bottom + 10, 20)),
            ],
          ),
        ],
      ),
    );
  }
}

class DialogBackground extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Container(
      color: Color.fromRGBO(0, 0, 0, 0.5),
      width: MediaQuery.of(context).size.width,
      height: MediaQuery.of(context).size.height,
    );
  }
}
